@@ -2,8 +2,8 @@
 from __future__ import annotations
 
 from dataclasses import dataclass
-from enum import Enum, IntEnum
-from typing import Any, Union
+from enum import IntEnum
+from typing import Any, Optional, Union
 
 from .events import EventType
 from .server_information import ServerInfo
@@ -15,7 +15,7 @@ class CommandMessage:
 
     message_id: str
     command: str
-    args: dict[str, Any] | None = None
+    args: Union[dict[str, Any], None] = None
 
 
 @dataclass
@@ -27,7 +27,7 @@ class ResultMessageBase:
 
 @dataclass
 class SuccessResultMessage(ResultMessageBase):
-    """Message sent when a Command has been succesfully executed."""
+    """Message sent when a Command has been successfully executed."""
 
     result: Any
 
@@ -43,10 +43,10 @@ class ErrorCode(IntEnum):
 
 @dataclass
 class ErrorResultMessage(ResultMessageBase):
-    """Message sent when a command did not execute succesfully"""
+    """Message sent when a command did not execute successfully."""
 
     error_code: ErrorCode
-    details: str | None = None
+    details: Optional[str] = None
 
 
 @dataclass
@@ -69,5 +69,3 @@ MessageType = Union[
     ErrorResultMessage,
     ServerInfoMessage,
 ]
-
-
